pub enum FastDivmod<I: FastDivmodInt> {
Fast {
divisor: I,
multiplier: I,
shift_right: u32,
},
Fallback {
divisor: I,
},
}Expand description
Create a fast-divmod object if supported, or a regular fallback if not. This precalculates certain values on the host, in exchange for making division and modulo operations on the GPU much faster. Only supports u32 right now to allow for a simpler algorithm. It’s mostly used for indices regardless.
Implementation based on ONNX: https://github.com/microsoft/onnxruntime/blob/main/onnxruntime/core/providers/cuda/shared_inc/fast_divmod.h
Variants
Implementations
Sourceimpl<I: FastDivmodInt> FastDivmod<I>
impl<I: FastDivmodInt> FastDivmod<I>
pub fn new_Fast(divisor: I, multiplier: I, shift_right: u32) -> Self
pub fn __expand_new_Fast( _: &Scope, divisor: <I as CubeType>::ExpandType, multiplier: <I as CubeType>::ExpandType, shift_right: <u32 as CubeType>::ExpandType, ) -> FastDivmodExpand<I>
pub fn new_Fallback(divisor: I) -> Self
pub fn __expand_new_Fallback( _: &Scope, divisor: <I as CubeType>::ExpandType, ) -> FastDivmodExpand<I>
Sourceimpl<I: FastDivmodInt> FastDivmod<I>
impl<I: FastDivmodInt> FastDivmod<I>
pub fn div(&self, dividend: I) -> I
pub fn modulo(&self, dividend: I) -> I
pub fn div_mod(&self, dividend: I) -> (I, I)
pub fn __expand_div( scope: &Scope, this: &<Self as CubeType>::ExpandType, dividend: <I as CubeType>::ExpandType, ) -> <I as CubeType>::ExpandType
pub fn __expand_modulo( scope: &Scope, this: &<Self as CubeType>::ExpandType, dividend: <I as CubeType>::ExpandType, ) -> <I as CubeType>::ExpandType
pub fn __expand_div_mod( scope: &Scope, this: &<Self as CubeType>::ExpandType, dividend: <I as CubeType>::ExpandType, ) -> (<I as CubeType>::ExpandType, <I as CubeType>::ExpandType)