pub struct ComptimeEventBus { /* private fields */ }Expand description
This event bus allows users to trigger events at compilation time to modify the generated code.
Warning
Recursion isn’t supported with a runtime end condition, the compilation will fail with a strange error.
Implementations
Sourceimpl ComptimeEventBus
impl ComptimeEventBus
Sourcepub fn listener<L: EventListener>(&mut self, listener: L)
pub fn listener<L: EventListener>(&mut self, listener: L)
Registers a new callback to be called when its event is launched.
Notes
Multiple listeners for a single event type is supported. All the listeners will be called for each event in the same order they were registered.
Sourcepub fn event<E: CubeType + 'static>(&mut self, event: E)
pub fn event<E: CubeType + 'static>(&mut self, event: E)
Registers a new event to be processed by registered listeners.
Sourcepub fn __expand_new(scope: &Scope) -> <Self as CubeType>::ExpandType
pub fn __expand_new(scope: &Scope) -> <Self as CubeType>::ExpandType
Creates a new event bus.
Sourcepub fn __expand_listener<L: EventListener>(
scope: &Scope,
this: &mut <Self as CubeType>::ExpandType,
listener: <L as CubeType>::ExpandType,
)
pub fn __expand_listener<L: EventListener>( scope: &Scope, this: &mut <Self as CubeType>::ExpandType, listener: <L as CubeType>::ExpandType, )
Registers a new callback to be called when its event is launched.
Notes
Multiple listeners for a single event type is supported. All the listeners will be called for each event in the same order they were registered.
Sourcepub fn __expand_event<E: CubeType + 'static>(
scope: &Scope,
this: &mut <Self as CubeType>::ExpandType,
event: <E as CubeType>::ExpandType,
)
pub fn __expand_event<E: CubeType + 'static>( scope: &Scope, this: &mut <Self as CubeType>::ExpandType, event: <E as CubeType>::ExpandType, )
Registers a new event to be processed by registered listeners.