pub struct ComptimeEventBusExpand { /* private fields */ }Implementations
Sourceimpl ComptimeEventBusExpand
impl ComptimeEventBusExpand
Sourcepub fn __expand_listener_method<L: EventListener>(
&mut self,
scope: &Scope,
listener: <L as CubeType>::ExpandType,
)
pub fn __expand_listener_method<L: EventListener>( &mut self, scope: &Scope, listener: <L as CubeType>::ExpandType, )
Registers a new callback to be called when its event is launched.
Notes
Multiple listeners for a single event type is supported. All the listeners will be called for each event in the same order they were registered.
Sourcepub fn __expand_event_method<E: CubeType + 'static>(
&mut self,
scope: &Scope,
event: <E as CubeType>::ExpandType,
)
pub fn __expand_event_method<E: CubeType + 'static>( &mut self, scope: &Scope, event: <E as CubeType>::ExpandType, )
Registers a new event to be processed by registered listeners.
Sourcepub fn __expand_new(scope: &Scope) -> Self
pub fn __expand_new(scope: &Scope) -> Self
Creates a new event bus.
Sourcepub fn __expand_listener<L: EventListener>(
scope: &Scope,
this: &mut Self,
listener: <L as CubeType>::ExpandType,
)
pub fn __expand_listener<L: EventListener>( scope: &Scope, this: &mut Self, listener: <L as CubeType>::ExpandType, )
Registers a new callback to be called when its event is launched.
Notes
Multiple listeners for a single event type is supported. All the listeners will be called for each event in the same order they were registered.
Sourcepub fn __expand_event<E: CubeType + 'static>(
scope: &Scope,
this: &mut Self,
event: <E as CubeType>::ExpandType,
)
pub fn __expand_event<E: CubeType + 'static>( scope: &Scope, this: &mut Self, event: <E as CubeType>::ExpandType, )
Registers a new event to be processed by registered listeners.