pub type NF = DynamicSize<_NF>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct NF { /* private fields */ }pub type NF = DynamicSize<_NF>;Type to be used as a generic for launch kernel argument.
pub struct NF { /* private fields */ }