pub type NQ = DynamicSize<_NQ>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct NQ { /* private fields */ }pub type NQ = DynamicSize<_NQ>;Type to be used as a generic for launch kernel argument.
pub struct NQ { /* private fields */ }