pub type S = DynamicScalar<_S>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct S { /* private fields */ }pub type S = DynamicScalar<_S>;Type to be used as a generic for launch kernel argument.
pub struct S { /* private fields */ }