Module dequantize_aligned_wide

Module dequantize_aligned_wide 

Structs

_F
_NF
_NQ

Functions

expand
[dequantize_aligned] for a scale a caller folded in f32, forming the product there too and narrowing only the result.

Type Aliases

F
Type to be used as a generic for launch kernel argument.
NF
Type to be used as a generic for launch kernel argument.
NQ
Type to be used as a generic for launch kernel argument.