Module e2m1_bits_to_float

Module e2m1_bits_to_float 

Structs

_F
_N

Functions

expand
Decode one e2m1 code per lane, held in the low nibble of each lane of code.

Type Aliases

F
Type to be used as a generic for launch kernel argument.
N
Type to be used as a generic for launch kernel argument.