Module float_to_e2m1_bits

Module float_to_e2m1_bits 

Structs

_F
_N

Functions

expand
Encode one e2m1 code per lane into the low nibble of each lane, rounding to nearest with ties to even and saturating at ±6.

Type Aliases

F
Type to be used as a generic for launch kernel argument.
N
Type to be used as a generic for launch kernel argument.