pub enum KnownScaleExpand {
None,
Global(<f32 as CubeType>::ExpandType),
Whole(<f32 as CubeType>::ExpandType),
}Variants
Implementations
Sourceimpl KnownScaleExpand
impl KnownScaleExpand
Sourcepub fn __expand_effective_method(
&self,
scope: &Scope,
scale: <f32 as CubeType>::ExpandType,
) -> <f32 as CubeType>::ExpandType
pub fn __expand_effective_method( &self, scope: &Scope, scale: <f32 as CubeType>::ExpandType, ) -> <f32 as CubeType>::ExpandType
The scale a value dequantizes against once scale, looked up for its position, meets what
this register holds.
Sourcepub fn __expand_effective(
scope: &Scope,
this: &Self,
scale: <f32 as CubeType>::ExpandType,
) -> <f32 as CubeType>::ExpandType
pub fn __expand_effective( scope: &Scope, this: &Self, scale: <f32 as CubeType>::ExpandType, ) -> <f32 as CubeType>::ExpandType
The scale a value dequantizes against once scale, looked up for its position, meets what
this register holds.