pub struct ReinterpretSlice<'a, S: CubePrimitive, T: CubePrimitive> { /* private fields */ }Expand description
This struct allows to take a slice of Vector<S> and reinterpret it
as a slice of T. Semantically, this is equivalent to reinterpreting the slice of Vector<S>
to a slice of T. When indexing, the index is valid in the casted list.
Warning
Currently, this only work with cube(launch_unchecked) and is not supported on wgpu.
Implementations
Sourceimpl<'a, S: CubePrimitive, T: CubePrimitive> ReinterpretSlice<'a, S, T>
impl<'a, S: CubePrimitive, T: CubePrimitive> ReinterpretSlice<'a, S, T>
pub fn new(slice: &'a [S]) -> ReinterpretSlice<'a, S, T>
pub fn read(&self, index: usize) -> T
pub fn __expand_new<'scope>( scope: &'scope Scope, slice: &'a <[S] as CubeType>::ExpandType, ) -> <ReinterpretSlice<'a, S, T> as CubeType>::ExpandType
pub fn __expand_read( scope: &Scope, this: &<Self as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, ) -> <T as CubeType>::ExpandType