ReinterpretSliceMut

Struct ReinterpretSliceMut 

pub struct ReinterpretSliceMut<'a, S: CubePrimitive, T: CubePrimitive> { /* private fields */ }
This struct allows to take a mutable slice of Vector<S> and reinterpret it as a mutable slice of T. Semantically, this is equivalent to reinterpreting the slice of Vector<S> to a mutable slice of T. When indexing, the index is valid in the casted list.

Warning

Currently, this only work with cube(launch_unchecked) and is not supported on wgpu.

Implementations

Source

impl<'a, S: CubePrimitive, T: CubePrimitive> ReinterpretSliceMut<'a, S, T>

pub fn new(slice: &'a mut [S]) -> ReinterpretSliceMut<'a, S, T>

pub fn read(&self, index: usize) -> T

pub fn write(&mut self, index: usize, value: T)

pub fn __expand_new<'scope>( scope: &'scope Scope, slice: &'a mut <[S] as CubeType>::ExpandType, ) -> <ReinterpretSliceMut<'a, S, T> as CubeType>::ExpandType

pub fn __expand_read( scope: &Scope, this: &<Self as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, ) -> <T as CubeType>::ExpandType

pub fn __expand_write( scope: &Scope, this: &mut <Self as CubeType>::ExpandType, index: <usize as CubeType>::ExpandType, value: <T as CubeType>::ExpandType, )