pub struct SwizzleExpand { /* private fields */ }Implementations
Sourceimpl SwizzleExpand
impl SwizzleExpand
Sourcepub fn __expand_apply_method(
&self,
scope: &Scope,
offset: <u32 as CubeType>::ExpandType,
type_size: usize,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_apply_method( &self, scope: &Scope, offset: <u32 as CubeType>::ExpandType, type_size: usize, ) -> <u32 as CubeType>::ExpandType
Apply the swizzle to a coordinate with a given item size. This is the size of the full type,
including vectorization.
offset should be in terms of vectors from the start of the buffer, and the buffer should be
aligned to repeats_after. This is to work around the fact we don’t currently support
retrieving the actual address of an offset.
If you’re using absolute/unvectorized indices, pass E::Scalar::type_size() instead of the full
vector size.
Sourcepub fn __expand_repeats_after_method(&self, scope: &Scope) -> u32
pub fn __expand_repeats_after_method(&self, scope: &Scope) -> u32
After how many elements this pattern repeats. Can be used to align the buffer (i.e. smem) so offsets match addresses.
Sourcepub fn __expand_new(scope: &Scope, bits: u32, base: u32, shift: i32) -> Self
pub fn __expand_new(scope: &Scope, bits: u32, base: u32, shift: i32) -> Self
Create a new swizzle with comptime parameters
Sourcepub fn __expand_none(scope: &Scope) -> Self
pub fn __expand_none(scope: &Scope) -> Self
Create a new noop swizzle object
Sourcepub fn __expand_apply(
scope: &Scope,
this: &Self,
offset: <u32 as CubeType>::ExpandType,
type_size: usize,
) -> <u32 as CubeType>::ExpandType
pub fn __expand_apply( scope: &Scope, this: &Self, offset: <u32 as CubeType>::ExpandType, type_size: usize, ) -> <u32 as CubeType>::ExpandType
Apply the swizzle to a coordinate with a given item size. This is the size of the full type,
including vectorization.
offset should be in terms of vectors from the start of the buffer, and the buffer should be
aligned to repeats_after. This is to work around the fact we don’t currently support
retrieving the actual address of an offset.
If you’re using absolute/unvectorized indices, pass E::Scalar::type_size() instead of the full
vector size.
Sourcepub fn __expand_repeats_after(scope: &Scope, this: &Self) -> u32
pub fn __expand_repeats_after(scope: &Scope, this: &Self) -> u32
After how many elements this pattern repeats. Can be used to align the buffer (i.e. smem) so offsets match addresses.