MatrixBatchLayout

Enum MatrixBatchLayout 

pub enum MatrixBatchLayout {
    Contiguous,
    MildlyPermuted {
        transposed: bool,
        batch_swap: bool,
    },
    HighlyPermuted,
}
Layout for matrix batch tensors, i.e. tensors whose interpretation is a bunch of batched matrices of 2 dimensions

Variants



Contiguous

Memory is wholly contiguous, with row major layout



MildlyPermuted

Permutations happened, but may not impact some kernels

Fields

transposed: bool

Last two dims are inverted

batch_swap: bool

Some permutations exist in batch dimensions



HighlyPermuted

Permutations happened between batch dimensions and last two dims