pub fn copy_into(
client: &Client,
input: TensorBinding,
output: TensorBinding,
dtype: ElemType,
)Expand description
Copies the input tensor into the output tensor following the strides.
pub fn copy_into(
client: &Client,
input: TensorBinding,
output: TensorBinding,
dtype: ElemType,
)Copies the input tensor into the output tensor following the strides.