pub fn into_contiguous_pitched(
client: &Client,
input: TensorBinding,
dtype: ElemType,
) -> TensorHandleExpand description
Make a jit tensor contiguous, using the pitched allocator if available.
See create_tensor.
pub fn into_contiguous_pitched(
client: &Client,
input: TensorBinding,
dtype: ElemType,
) -> TensorHandleMake a jit tensor contiguous, using the pitched allocator if available.
See create_tensor.