launch_into_contiguous_perpendicular

Function launch_into_contiguous_perpendicular 

pub fn launch_into_contiguous_perpendicular(
    client: &Client,
    input: TensorBinding,
    dtype: ElemType,
) -> TensorHandle
Launches the perpendicular contiguous kernel.

This is used when the input tensor’s memory layout is such that the last dimension is not the one with a stride of 1 (the vectorized dimension). It optimizes the copy by using hardware vectorization (Vectors) and an in-register transpose.