Module index_offset_contiguous

Module index_offset_contiguous 

Structs

_N

Functions

expand
Returns the offset of the tensor corresponding to a contiguous layout.

Type Aliases

N
Type to be used as a generic for launch kernel argument.