Module index_offset_with_layout

Module index_offset_with_layout 

Structs

_N1
_N2

Functions

expand
Returns the offset of the tensor corresponding to the layout tensor.

Type Aliases

N1
Type to be used as a generic for launch kernel argument.
N2
Type to be used as a generic for launch kernel argument.