IntoDynExpand

Trait IntoDynExpand 

pub trait IntoDynExpand {
    // Required method
    fn __expand_into_dyn_method(
        self,
        scope: &mut Scope,
    ) -> <Sequence<i32> as CubeType>::ExpandType;
}
Coordinates that can be converted to a dynamic sequence of signed coordinates. Can be used to convert any set of coordinates to a comptime-sized sequence for use with TMA.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoDynExpand for SequenceExpand<i32>

Source

impl IntoDynExpand for SequenceExpand<u32>

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg, T9: Coordinates + CubePrimitive + LaunchArg, T10: Coordinates + CubePrimitive + LaunchArg, T11: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>, NativeExpand<T5>, NativeExpand<T6>, NativeExpand<T7>, NativeExpand<T8>, NativeExpand<T9>, NativeExpand<T10>, NativeExpand<T11>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg, T9: Coordinates + CubePrimitive + LaunchArg, T10: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>, NativeExpand<T5>, NativeExpand<T6>, NativeExpand<T7>, NativeExpand<T8>, NativeExpand<T9>, NativeExpand<T10>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg, T9: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>, NativeExpand<T5>, NativeExpand<T6>, NativeExpand<T7>, NativeExpand<T8>, NativeExpand<T9>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>, NativeExpand<T5>, NativeExpand<T6>, NativeExpand<T7>, NativeExpand<T8>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>, NativeExpand<T5>, NativeExpand<T6>, NativeExpand<T7>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>, NativeExpand<T5>, NativeExpand<T6>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>, NativeExpand<T5>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>, NativeExpand<T4>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>, NativeExpand<T3>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>, NativeExpand<T2>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (NativeExpand<T0>, NativeExpand<T1>)

Implementors