pub struct FixedDimLayoutExpand<D: IntoDyn> { /* private fields */ }Trait Implementations
Sourceimpl<D: IntoDyn> AsMutExpand for FixedDimLayoutExpand<D>
impl<D: IntoDyn> AsMutExpand for FixedDimLayoutExpand<D>
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl<D: IntoDyn> AsRefExpand for FixedDimLayoutExpand<D>
impl<D: IntoDyn> AsRefExpand for FixedDimLayoutExpand<D>
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl<D: IntoDyn> CubeDebug for FixedDimLayoutExpand<D>
impl<D: IntoDyn> CubeDebug for FixedDimLayoutExpand<D>
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl<D: IntoDyn> ExpandTypeClone for FixedDimLayoutExpand<D>
impl<D: IntoDyn> ExpandTypeClone for FixedDimLayoutExpand<D>
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl<D: IntoDyn> IntoExpand for FixedDimLayoutExpand<D>
impl<D: IntoDyn> IntoExpand for FixedDimLayoutExpand<D>
type Expand = FixedDimLayoutExpand<D>
fn into_expand(self, _: &Scope) -> Self
Sourceimpl<D: IntoDyn> IntoMut for FixedDimLayoutExpand<D>
impl<D: IntoDyn> IntoMut for FixedDimLayoutExpand<D>
Sourceimpl<D: IntoDyn> LayoutExpand for FixedDimLayoutExpand<D>
impl<D: IntoDyn> LayoutExpand for FixedDimLayoutExpand<D>
Sourcetype Coordinates = D
type Coordinates = D
The coordinate type used by the conceptual tensor represented by this layout, i.e.
(u32, u32, u32) for a fixed-rank 3D tensor.
This does not have to match the rank of the underlying storage (if applicable).
It’s only how the tensor is interpreted (viewed) by the code.Sourcetype SourceCoordinates = usize
type SourceCoordinates = usize
The coordinate type used by the inner storage wrapped in this layout, i.e.
u32 for
Array, or (u32, u32) for a 2D view.fn __expand_to_source_pos_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> <Self::SourceCoordinates as CubeType>::ExpandType
fn __expand_is_in_bounds_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
fn __expand_to_source_pos_checked_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> (<Self::SourceCoordinates as CubeType>::ExpandType, <bool as CubeType>::ExpandType)
fn __expand_shape_method( &self, scope: &Scope, ) -> <Self::Coordinates as CubeType>::ExpandType