Module linear

Module linear 

Structs

LinearViewLayoutLaunch

Enums

LinearLayoutCompilationArg
LinearViewLayout
Maps a linear index based on vector count to a potentially strided tensor. Only applies the necessary level of striding, either none, only the last dim (for freshly allocated strided tensors), or all dimensions.
LinearViewLayoutExpand

Functions

linear_layout
Create a linear layout from a handle and vector size
linear_view
Create a linear tensor view from a handle
linear_view_alias
linear_view_with_reference
Create a possibly broadcast linear tensor view from a handle and reference handle

Type Aliases

LinearLayout
Concrete version of the layout, so it can be launched on its own
LinearLayoutLaunch
LinearView
View with a linear layout inferred from the shape/strides at launch. Useful for elementwise kernels.
LinearViewLaunch
Launch type for LinearView.