pub fn linear_layout(
handle: &TensorBinding,
vector_size: VectorSize,
) -> LinearLayoutLaunchExpand description
Create a linear layout from a handle and vector size
pub fn linear_layout(
handle: &TensorBinding,
vector_size: VectorSize,
) -> LinearLayoutLaunchCreate a linear layout from a handle and vector size