LinearViewLayoutLaunch

Struct LinearViewLayoutLaunch 

pub struct LinearViewLayoutLaunch { /* private fields */ }

Implementations

Source

impl LinearViewLayoutLaunch

pub fn new() -> Self

Construct a linear layout from shapes, strides and vector size of the tensor

pub fn from_reference_shape(reference_shape: Shape) -> Self

Construct a possibly broadcast linear layout from shapes/strides and a reference shape

pub fn from_reference_handle<R: Runtime>(reference: TensorBinding<R>) -> Self

Construct a possibly broadcast linear layout from a tensor handle and reference handle