pub struct SimpleLayout { /* private fields */ }Expand description
Layout for contiguous tensors, indexed in individual elements.
Differs from PlainLayout because PlainLayout expects vector indices, not element indices.
Implementations
Sourceimpl SimpleLayout
impl SimpleLayout
Sourcepub fn new(len: usize, vector_size: VectorSize) -> Self
pub fn new(len: usize, vector_size: VectorSize) -> Self
Create a new simple layout with a length and vector size.
Note
Length should be in elements, not vectors!
Sourcepub fn __expand_new(
scope: &Scope,
len: <usize as CubeType>::ExpandType,
vector_size: VectorSize,
) -> <Self as CubeType>::ExpandType
pub fn __expand_new( scope: &Scope, len: <usize as CubeType>::ExpandType, vector_size: VectorSize, ) -> <Self as CubeType>::ExpandType
Create a new simple layout with a length and vector size.
Note
Length should be in elements, not vectors!