pub struct TensorHandle {
pub handle: Handle,
pub metadata: Box<Metadata>,
pub dtype: ElemType,
}Expand description
Tensor representation containing a server handle as well as basic tensor metadata.,
Fields
handle: HandleThe buffer where the data are stored.
metadata: Box<Metadata>dtype: ElemTypeThe type used as storage.
Implementations
Sourceimpl TensorHandle
impl TensorHandle
Sourcepub fn new(
handle: Handle,
shape: impl Into<Shape>,
strides: impl Into<Strides>,
storage: impl Into<Type>,
) -> Self
pub fn new( handle: Handle, shape: impl Into<Shape>, strides: impl Into<Strides>, storage: impl Into<Type>, ) -> Self
Create a new tensor.
Sourcepub fn from_metadata(
handle: Handle,
metadata: Metadata,
storage: impl Into<Type>,
) -> Self
pub fn from_metadata( handle: Handle, metadata: Metadata, storage: impl Into<Type>, ) -> Self
A tensor over metadata as it is, tiling included: the constructor for a handle rebuilt
from another’s metadata, where new would rebuild an untiled one from the
shape and strides alone.
pub fn empty( client: &Client, shape: impl Into<Shape>, storage: impl Into<Type>, ) -> Self
Sourcepub fn new_contiguous(
shape: impl Into<Shape>,
handle: Handle,
storage: ElemType,
) -> Self
pub fn new_contiguous( shape: impl Into<Shape>, handle: Handle, storage: ElemType, ) -> Self
Create a new tensor with a contiguous memory layout.
pub fn binding(self) -> TensorBinding
pub fn into_copy_descriptor(self) -> CopyDescriptor
pub fn required_address_type(&self) -> AddressType
pub fn shape(&self) -> &Shape
pub fn strides(&self) -> &Strides