Module launch

Module launch 

Structs

ConcreteLayout
ConcreteLayoutCompilationArg
ConcreteLayoutExpand
ConcreteLayoutLaunch
VirtualViewLayoutCompilationArg
VirtualViewLayoutLaunch

Enums

ViewArg
ViewCompilationArg

Traits

BufferArg
ViewLayoutLaunchArg
Special launch arg that gets the handle and types of the view, to allow inferring launch state based on type/handle metadata, avoiding duplication. All LaunchArgs also implement this trait.