View

Struct View 

pub struct View<'a, E: CubePrimitive, C: Coordinates> { /* private fields */ }
A conceptual view of an underlying linear storage. Allows abstract indexing in multiple dimensions, without having to know the data layout or location.

Implementations

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'a> View<'a, E, C>

pub fn new<V: ViewOperations<E, S> + 'a, S: Coordinates>( view: V, layout: impl Into<VirtualLayout<C, S>>, ) -> Self

Create a new tensor view from an underlying concrete storage and a layout to map it into the target coordinate space

pub fn __expand_new<V: ViewOperations<E, S> + 'a, S: Coordinates + 'a>( scope: &Scope, view: V::ExpandType, layout: VirtualLayoutExpand<C, S>, ) -> ViewExpand<'a, E, C>

Expand function for View::new

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'a> View<'a, E, C>

pub fn view<T: Coordinates + 'a>( self, _layout: impl Into<VirtualLayout<T, C>>, ) -> View<'a, E, T>

pub fn __expand_view<T: Coordinates + 'a>( scope: &Scope, this: ViewExpand<'a, E, C>, layout: VirtualLayoutExpand<T, C>, ) -> ViewExpand<'a, E, T>

Source

impl<'a, E: CubePrimitive, C: Coordinates> View<'a, E, C>

pub fn shape(&self) -> C

Calls Layout::shape on the view’s layout

pub fn is_in_bounds(&self, pos: C) -> bool

Calls Layout::is_in_bounds on the view’s layout

pub fn __expand_shape( scope: &Scope, this: &<Self as CubeType>::ExpandType, ) -> <C as CubeType>::ExpandType

Calls Layout::shape on the view’s layout

pub fn __expand_is_in_bounds( scope: &Scope, this: &<Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType

Calls Layout::is_in_bounds on the view’s layout

Source

impl<'a, E: CubePrimitive, C: Coordinates> View<'a, E, C>

pub fn read(&self, pos: C) -> E

Read a value at pos. The layout handles translation into a concrete index.

pub fn read_unchecked(&self, pos: C) -> E

Read a value at pos. The layout handles translation into a concrete index. Reading is done unchecked

pub fn read_checked(&self, pos: C) -> E

Read a value at pos if it’s in bounds. The layout handles translation into a concrete index.

pub fn read_masked(&self, pos: C, mask_value: E) -> E

Read a value at pos if it’s in bounds, returning mask_value otherwise. The layout handles translation into a concrete index.

pub fn as_linear_slice(&self) -> &'a [E]

Interpret this view as a linear slice encompassing the entire view.

Safety

No checking is done on whether the slice is contiguous in memory.

pub fn vector_size(&self) -> VectorSize

pub fn __expand_read( scope: &Scope, this: &<Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos. The layout handles translation into a concrete index.

pub fn __expand_read_unchecked( scope: &Scope, this: &<Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos. The layout handles translation into a concrete index. Reading is done unchecked

pub fn __expand_read_checked( scope: &Scope, this: &<Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos if it’s in bounds. The layout handles translation into a concrete index.

pub fn __expand_read_masked( scope: &Scope, this: &<Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, mask_value: <E as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos if it’s in bounds, returning mask_value otherwise. The layout handles translation into a concrete index.

pub fn __expand_as_linear_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer <Self as CubeType>::ExpandType, ) -> &'a <[E] as CubeType>::ExpandType

Interpret this view as a linear slice encompassing the entire view.

Safety

No checking is done on whether the slice is contiguous in memory.

pub fn __expand_vector_size( scope: &Scope, this: &<Self as CubeType>::ExpandType, ) -> VectorSize

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'static> View<'a, E, C>

pub fn slice(self, pos: C, size: C) -> View<'a, E, C>

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size will be clamped to the current layout size.

pub fn slice_unchecked(self, pos: C, size: C) -> View<'a, E, C>

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size. #Safety Access is always unchecked

pub fn __expand_slice<'scope>( scope: &'scope Scope, this: <Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <View<'a, E, C> as CubeType>::ExpandType

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size will be clamped to the current layout size.

pub fn __expand_slice_unchecked<'scope>( scope: &'scope Scope, this: <Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <View<'a, E, C> as CubeType>::ExpandType

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size. #Safety Access is always unchecked

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'a> View<'a, E, C>

pub fn tensor_map_load( &self, barrier: &Barrier, shared_memory: &mut [E], pos: C, )

Execute a TMA load into shared memory, if the underlying storage supports it. Panics if it’s unsupported.

pub fn __expand_tensor_map_load( scope: &Scope, this: &<Self as CubeType>::ExpandType, barrier: &<Barrier as CubeType>::ExpandType, shared_memory: &mut <[E] as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, )

Execute a TMA load into shared memory, if the underlying storage supports it. Panics if it’s unsupported.