ViewMutExpand

Struct ViewMutExpand 

pub struct ViewMutExpand<'a, E: CubePrimitive, C: Coordinates> { /* private fields */ }
Expand type of ViewMutExpand

Implementations

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'a> ViewMutExpand<'a, E, C>

pub fn __expand_view_method<T: Coordinates + 'a>( self, scope: &Scope, layout: VirtualLayoutExpand<T, C>, ) -> ViewMutExpand<'a, E, T>

Source

impl<'a, E: CubePrimitive, C: Coordinates> ViewMutExpand<'a, E, C>

pub fn __expand_shape_method( &self, scope: &Scope, ) -> <C as CubeType>::ExpandType

Calls Layout::shape on the view’s layout

pub fn __expand_is_in_bounds_method( &self, scope: &Scope, pos: <C as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType

Calls Layout::is_in_bounds on the view’s layout

pub fn __expand_shape(scope: &Scope, this: &Self) -> <C as CubeType>::ExpandType

Calls Layout::shape on the view’s layout

pub fn __expand_is_in_bounds( scope: &Scope, this: &Self, pos: <C as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType

Calls Layout::is_in_bounds on the view’s layout

Source

impl<'a, E: CubePrimitive, C: Coordinates> ViewMutExpand<'a, E, C>

pub fn __expand_read_method( &self, scope: &Scope, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos. The layout handles translation into a concrete index.

pub fn __expand_read_unchecked_method( &self, scope: &Scope, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos. The layout handles translation into a concrete index. Reading is done unchecked

pub fn __expand_read_checked_method( &self, scope: &Scope, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos if it’s in bounds. The layout handles translation into a concrete index.

pub fn __expand_read_masked_method( &self, scope: &Scope, pos: <C as CubeType>::ExpandType, mask_value: <E as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos if it’s in bounds, returning mask_value otherwise. The layout handles translation into a concrete index.

pub fn __expand_as_linear_slice_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, ) -> &'a <[E] as CubeType>::ExpandType

Interpret this view as a linear slice encompassing the entire view.

Safety

No checking is done on whether the slice is contiguous in memory.

pub fn __expand_vector_size_method(&self, scope: &Scope) -> VectorSize

pub fn __expand_read( scope: &Scope, this: &Self, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos. The layout handles translation into a concrete index.

pub fn __expand_read_unchecked( scope: &Scope, this: &Self, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos. The layout handles translation into a concrete index. Reading is done unchecked

pub fn __expand_read_checked( scope: &Scope, this: &Self, pos: <C as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos if it’s in bounds. The layout handles translation into a concrete index.

pub fn __expand_read_masked( scope: &Scope, this: &Self, pos: <C as CubeType>::ExpandType, mask_value: <E as CubeType>::ExpandType, ) -> <E as CubeType>::ExpandType

Read a value at pos if it’s in bounds, returning mask_value otherwise. The layout handles translation into a concrete index.

pub fn __expand_as_linear_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, ) -> &'a <[E] as CubeType>::ExpandType

Interpret this view as a linear slice encompassing the entire view.

Safety

No checking is done on whether the slice is contiguous in memory.

pub fn __expand_vector_size(scope: &Scope, this: &Self) -> VectorSize

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'static> ViewMutExpand<'a, E, C>

pub fn __expand_slice_method<'scope>( self, scope: &'scope Scope, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size will be clamped to the current layout size.

pub fn __expand_slice_unchecked_method<'scope>( self, scope: &'scope Scope, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size. #Safety Access is always unchecked

pub fn __expand_slice<'scope>( scope: &'scope Scope, this: Self, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size will be clamped to the current layout size.

pub fn __expand_slice_unchecked<'scope>( scope: &'scope Scope, this: Self, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size. #Safety Access is always unchecked

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'a> ViewMutExpand<'a, E, C>

pub fn __expand_tensor_map_load_method( &self, scope: &Scope, barrier: &<Barrier as CubeType>::ExpandType, shared_memory: &mut <[E] as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, )

Execute a TMA load into shared memory, if the underlying storage supports it. Panics if it’s unsupported.

pub fn __expand_tensor_map_load( scope: &Scope, this: &Self, barrier: &<Barrier as CubeType>::ExpandType, shared_memory: &mut <[E] as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, )

Execute a TMA load into shared memory, if the underlying storage supports it. Panics if it’s unsupported.

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'a> ViewMutExpand<'a, E, C>

pub fn __expand_as_read_method(self, _scope: &Scope) -> ViewExpand<'a, E, C>

Source

impl<'a, E: CubePrimitive, C: Coordinates> ViewMutExpand<'a, E, C>

pub fn new<V: ViewOperationsMutExpand<E, C> + 'a>( scope: &Scope, view: V, ) -> Self

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'a> ViewMutExpand<'a, E, C>

pub fn __expand_view_mut_method<'b, T: Coordinates + 'a>( self, scope: &Scope, layout: VirtualLayoutExpand<T, C>, ) -> ViewMutExpand<'b, E, T>
where 'a: 'b,

Source

impl<'a, E: CubePrimitive, C: Coordinates> ViewMutExpand<'a, E, C>

pub fn __expand_write_method( &mut self, scope: &Scope, pos: <C as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, )

Write a value to pos. The layout handles translation into a concrete index.

pub fn __expand_write_checked_method( &mut self, scope: &Scope, pos: <C as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, )

Write a value to pos if it’s in bounds. The layout handles translation into a concrete index.

pub fn __expand_as_linear_slice_mut_method<'infer, 'scope>( &'infer mut self, scope: &'scope Scope, ) -> &'a mut <[E] as CubeType>::ExpandType

Interpret this view as a mutable linear slice encompassing the entire view.

Safety

No checking is done on whether the slice is contiguous in memory.

pub fn __expand_write( scope: &Scope, this: &mut Self, pos: <C as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, )

Write a value to pos. The layout handles translation into a concrete index.

pub fn __expand_write_checked( scope: &Scope, this: &mut Self, pos: <C as CubeType>::ExpandType, value: <E as CubeType>::ExpandType, )

Write a value to pos if it’s in bounds. The layout handles translation into a concrete index.

pub fn __expand_as_linear_slice_mut<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut Self, ) -> &'a mut <[E] as CubeType>::ExpandType

Interpret this view as a mutable linear slice encompassing the entire view.

Safety

No checking is done on whether the slice is contiguous in memory.

Source

impl<'a, E: CubePrimitive, C: Coordinates + 'static> ViewMutExpand<'a, E, C>

pub fn __expand_slice_mut_method<'scope>( self, scope: &'scope Scope, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a mutable slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size.

pub fn __expand_slice_mut_unchecked_method<'scope>( self, scope: &'scope Scope, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a mutable slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size.

Safety

Access is always unchecked.

pub fn __expand_slice_mut<'scope>( scope: &'scope Scope, this: Self, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a mutable slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size.

pub fn __expand_slice_mut_unchecked<'scope>( scope: &'scope Scope, this: Self, pos: <C as CubeType>::ExpandType, size: <C as CubeType>::ExpandType, ) -> <ViewMut<'a, E, C> as CubeType>::ExpandType

Create a mutable slice starting from pos, with size. The layout handles translation into concrete indices. Size and pos will be clamped to the current layout size.

Safety

Access is always unchecked.

Source

impl<'a, E: CubePrimitive, C: Coordinates> ViewMutExpand<'a, E, C>

pub fn __expand_tensor_map_store_method( &self, scope: &Scope, shared_memory: &<[E] as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, )

Execute a TMA store into global memory, if the underlying storage supports it. Panics if it’s unsupported.

pub fn __expand_tensor_map_store( scope: &Scope, this: &Self, shared_memory: &<[E] as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, )

Execute a TMA store into global memory, if the underlying storage supports it. Panics if it’s unsupported.