Module virtual

Module virtual 

Structs

VirtualTensor
Tensor representation that is decoupled from how the tensor is stored.
VirtualTensorExpand
Expand type for VirtualTensor.

Traits

VirtualTensorOperations
Trait to be implemented by a type that can become a virtual tensor.
VirtualTensorOperationsExpand
Trait to be implemented by a type that can become a virtual tensor.