VirtualTensorExpand

Struct VirtualTensorExpand 

pub struct VirtualTensorExpand<E: Numeric, N: Size, IO> { /* private fields */ }
Expand type for VirtualTensor.

Implementations

Source

impl<E: Numeric, N: Size, IO: Clone> VirtualTensorExpand<E, N, IO>

pub fn __expand_read_method( &self, scope: &Scope, index: <usize as CubeType>::ExpandType, ) -> <Vector<E, N> as CubeType>::ExpandType

pub fn __expand_len_method( &self, scope: &Scope, ) -> <usize as CubeType>::ExpandType

pub fn __expand_read( scope: &Scope, this: &Self, index: <usize as CubeType>::ExpandType, ) -> <Vector<E, N> as CubeType>::ExpandType

pub fn __expand_len( scope: &Scope, this: &Self, ) -> <usize as CubeType>::ExpandType

Source

impl<E: Numeric, N: Size, IO: Clone> VirtualTensorExpand<E, N, IO>

pub fn __expand_as_slice_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, ) -> &'infer <[Vector<E, N>] as CubeType>::ExpandType

pub fn __expand_as_mut_slice_method<'infer, 'scope>( &'infer mut self, scope: &'scope Scope, ) -> &'infer mut <[Vector<E, N>] as CubeType>::ExpandType

pub fn __expand_as_tensor_map_method( &self, scope: &Scope, ) -> <ComptimeOption<TensorMap<E, Tiled>> as CubeType>::ExpandType

pub fn __expand_slice_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, start: <usize as CubeType>::ExpandType, end: <usize as CubeType>::ExpandType, ) -> &'infer <[Vector<E, N>] as CubeType>::ExpandType

pub fn __expand_shape_method( &self, scope: &Scope, axis: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

Get the shape of the tensor at the given axis.

pub fn __expand_stride_method( &self, scope: &Scope, axis: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

Get the stride of the tensor at the given axis.

pub fn __expand_rank_method( &self, scope: &Scope, ) -> <usize as CubeType>::ExpandType

Get the rank of the tensor.

pub fn __expand_buffer_len_method( &self, scope: &Scope, ) -> <usize as CubeType>::ExpandType

pub fn __expand_as_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, ) -> &'infer <[Vector<E, N>] as CubeType>::ExpandType

pub fn __expand_as_mut_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut Self, ) -> &'infer mut <[Vector<E, N>] as CubeType>::ExpandType

pub fn __expand_as_tensor_map( scope: &Scope, this: &Self, ) -> <ComptimeOption<TensorMap<E, Tiled>> as CubeType>::ExpandType

pub fn __expand_slice<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, start: <usize as CubeType>::ExpandType, end: <usize as CubeType>::ExpandType, ) -> &'infer <[Vector<E, N>] as CubeType>::ExpandType

pub fn __expand_shape( scope: &Scope, this: &Self, axis: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

Get the shape of the tensor at the given axis.

pub fn __expand_stride( scope: &Scope, this: &Self, axis: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

Get the stride of the tensor at the given axis.

pub fn __expand_rank( scope: &Scope, this: &Self, ) -> <usize as CubeType>::ExpandType

Get the rank of the tensor.

pub fn __expand_buffer_len( scope: &Scope, this: &Self, ) -> <usize as CubeType>::ExpandType

Source

impl<E: Numeric, N: Size, IO: Clone + 'static> VirtualTensorExpand<E, N, IO>

pub fn __expand_as_view_method<'infer, 'scope>( &'infer self, scope: &'scope Scope, ) -> <View<'infer, Vector<E, N>, usize> as CubeType>::ExpandType

Create a conceptual view over this tensor, with a simple linear layout

pub fn __expand_as_view<'infer, 'scope>( scope: &'scope Scope, this: &'infer Self, ) -> <View<'infer, Vector<E, N>, usize> as CubeType>::ExpandType

Create a conceptual view over this tensor, with a simple linear layout

Source

impl<E: Numeric, N: Size, IO: Clone + 'static> VirtualTensorExpand<E, N, IO>

pub fn __expand_view_method<C: Coordinates + 'static>( &self, scope: &Scope, layout: VirtualLayoutExpand<C, Coords1d>, ) -> ViewExpand<'_, Vector<E, N>, C>

Create a conceptual view over this tensor, allowing for multi-dimensional indexing with custom layouts

pub fn __expand_into_view_method<C: Coordinates + 'static>( self, scope: &Scope, layout: VirtualLayoutExpand<C, Coords1d>, ) -> ViewExpand<'static, Vector<E, N>, C>

Source

impl<E: Numeric, N: Size> VirtualTensorExpand<E, N, ReadWrite>

pub fn __expand_view_mut_method<C: Coordinates + 'static>( &mut self, scope: &Scope, layout: VirtualLayoutExpand<C, Coords1d>, ) -> ViewMutExpand<'_, Vector<E, N>, C>

pub fn __expand_into_view_mut_method<C: Coordinates + 'static>( self, scope: &Scope, layout: VirtualLayoutExpand<C, Coords1d>, ) -> ViewMutExpand<'static, Vector<E, N>, C>

Source

impl<E: Numeric, N: Size> VirtualTensorExpand<E, N, ReadWrite>

pub fn __expand_as_view_mut_method<'infer, 'scope>( &'infer mut self, scope: &'scope Scope, ) -> <ViewMut<'infer, Vector<E, N>, usize> as CubeType>::ExpandType

Create a conceptual mutable view over this tensor, with a simple linear layout

pub fn __expand_as_view_mut<'infer, 'scope>( scope: &'scope Scope, this: &'infer mut Self, ) -> <ViewMut<'infer, Vector<E, N>, usize> as CubeType>::ExpandType

Create a conceptual mutable view over this tensor, with a simple linear layout

Source

impl<E: Numeric, N: Size, IO: Clone + 'static> VirtualTensorExpand<E, N, IO>

pub fn __expand_coordinate_method( &self, scope: &Scope, index: <usize as CubeType>::ExpandType, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

pub fn __expand_coordinate( scope: &Scope, this: &Self, index: <usize as CubeType>::ExpandType, dim: <usize as CubeType>::ExpandType, ) -> <usize as CubeType>::ExpandType

Source

impl<E: Numeric, N: Size> VirtualTensorExpand<E, N, ReadWrite>

pub fn __expand_write_method( &mut self, scope: &Scope, index: <usize as CubeType>::ExpandType, value: <Vector<E, N> as CubeType>::ExpandType, )

pub fn __expand_write( scope: &Scope, this: &mut Self, index: <usize as CubeType>::ExpandType, value: <Vector<E, N> as CubeType>::ExpandType, )