pub fn device_throughput<R: Runtime>(
device: &R::Device,
keys: &[ThroughputKey],
) -> Vec<Result<ThroughputValue, ThroughputError>>Expand description
Measure peak throughput on device for each of the given keys.
pub fn device_throughput<R: Runtime>(
device: &R::Device,
keys: &[ThroughputKey],
) -> Vec<Result<ThroughputValue, ThroughputError>>Measure peak throughput on device for each of the given keys.