pub fn measure_peak_throughput<R: Runtime>(
client: &ComputeClient<R>,
key: ThroughputKey,
) -> ThroughputValueExpand description
Computes the peak throughput for a given runtime and key.
Native only, panics on WASM
pub fn measure_peak_throughput<R: Runtime>(
client: &ComputeClient<R>,
key: ThroughputKey,
) -> ThroughputValueComputes the peak throughput for a given runtime and key.
Native only, panics on WASM