Module launch_overhead
cubecl_
std
0.11.0-pre.2
Module launch_
overhead
Module Items
Structs
Functions
Type Aliases
In cubecl_
std::
throughput::
launch_
overhead
cubecl_std
::
throughput
::
launch_overhead
Module
launch_
overhead
Structs

Launch
Overhead
launch_overhead Kernel
Launch
Overhead
Info
_I
_N
Functions

expand
launch_
unchecked
⚠
Launch the kernel
launch_overhead()
on the given runtime without bound checks.
Type Aliases

I
Type to be used as a generic for launch kernel argument.
N
Type to be used as a generic for launch kernel argument.