Modules
Functions
- build_
kernel - Builds the copy kernel, moving
working_setbytes per pass: half read out of the input buffer, half written into the output one. - memory_
direct_ throughput
working_set bytes per pass: half read out
of the input buffer, half written into the output one.