Skip to main contentModule float_to_e2m1_bits
Source - _F
- _N
- expand
- Encode one
e2m1 code per lane into the low nibble of each lane, rounding to nearest with
ties to even and saturating at ±6.
- F
- Type to be used as a generic for launch kernel argument.
- N
- Type to be used as a generic for launch kernel argument.