Module view

Module view 

Structs

QuantizedView
View that dequantizes after loads. Scales layout should take values coordinates and map them to the corresponding scale.
QuantizedViewCompilationArg
QuantizedViewExpand
QuantizedViewLaunch

Functions

run_with_quant_type
Run a function with the quantization storage type and scale. Useful when concrete types are required but aren’t available, and only the dynamic schema is known.