pub struct QuantizedView<'a, Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> { /* private fields */ }Expand description
View that dequantizes after loads. Scales layout should take values coordinates and map them to the corresponding scale.
Warning
Assumes only one scale maps to a single load. Adjust vector size of values or block size to ensure
this.
Must ensure block_size.is_multiple_of(vector_size * scheme.num_quants()).
Implementations
Sourceimpl<'a, Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<'a, Q, NQ, S, F, NF, C>
impl<'a, Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<'a, Q, NQ, S, F, NF, C>
pub fn new( values: View<'a, Vector<Q, NQ>, C>, scales: View<'a, S, C>, scheme: QuantScheme, ) -> Self
pub fn __expand_new( scope: &Scope, values: <View<'a, Vector<Q, NQ>, C> as CubeType>::ExpandType, scales: <View<'a, S, C> as CubeType>::ExpandType, scheme: QuantScheme, ) -> <Self as CubeType>::ExpandType
Sourceimpl<'a, Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<'a, Q, NQ, S, F, NF, C>
impl<'a, Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<'a, Q, NQ, S, F, NF, C>
pub fn view(self) -> View<'a, Vector<F, NF>, C>
pub fn __expand_view( scope: &Scope, this: QuantizedViewExpand<'a, Q, NQ, S, F, NF, C>, ) -> ViewExpand<'a, Vector<F, NF>, C>