pub struct QuantizedView<Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> { /* private fields */ }Expand description
View that dequantizes after loads. Scales layout should take values coordinates and map them to the corresponding scale.
Warning
Assumes only one scale maps to a single load. Adjust vector size of values or block size to ensure
this.
Must ensure block_size.is_multiple_of(vector_size * scheme.num_quants()).
Implementations
Sourceimpl<Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<Q, NQ, S, F, NF, C>
impl<Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<Q, NQ, S, F, NF, C>
pub fn new( values: View<Vector<Q, NQ>, C>, scales: View<S, C>, scheme: QuantScheme, ) -> Self
pub fn __expand_new( scope: &mut Scope, values: <View<Vector<Q, NQ>, C> as CubeType>::ExpandType, scales: <View<S, C> as CubeType>::ExpandType, scheme: QuantScheme, ) -> <Self as CubeType>::ExpandType
Sourceimpl<Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<Q, NQ, S, F, NF, C>
impl<Q: Scalar, NQ: Size, S: Scalar, F: Numeric, NF: Size, C: Coordinates + 'static> QuantizedView<Q, NQ, S, F, NF, C>
pub fn view(self) -> View<Vector<F, NF>, C>
pub fn __expand_view( scope: &mut Scope, this: QuantizedViewExpand<Q, NQ, S, F, NF, C>, ) -> ViewExpand<Vector<F, NF>, C, ReadOnly>