Re-exports
Modules
- identity
- index_
offset_ contiguous - index_
offset_ contiguous_ fastdivmod - index_
offset_ with_ layout - layout
- view
- virtual
Structs
- Erased
Tensor - A tensor that has forgotten its line width. See the module docs.
- Erased
Tensor Expand - Expand type for
ErasedTensor. - Erased
View - Any view, at a width named once here and forgotten after.
- Erased
View Mut - Any mutable view. As
ErasedView, with the write half as well. - Tensor
Handle - Tensor representation containing a server handle as well as basic tensor metadata.,
- Write
Only - Visibility marker for a destination that is written and never read.
Enums
- Matrix
Batch Layout - Layout for matrix batch tensors, i.e. tensors whose interpretation is a bunch of batched matrices of 2 dimensions
Constants
Traits
- Erased
Backing - A backing that can be wrapped at visibility
IO. - Erased
Io - The visibility markers an
ErasedTensoraccepts. - Erased
IoRead - A visibility that permits reads.
- Erased
IoWrite - A visibility that permits writes.
- Erased
Tensor Operations Expand - What a backing has to answer to be an
ErasedTensor. - Reads
Lines - A backing whose
__expand_read_line_methodis real rather than the default. - Writes
Lines - A backing whose
__expand_write_line_methodis real rather than the default.
Functions
- compact_
strides - copy_
gpu_ ref - Make a jit tensor contiguous.
- copy_
into - Copies the input tensor into the output tensor following the strides.
- index_
offset_ contiguous - Returns the offset of the tensor corresponding to a contiguous layout.
- index_
offset_ contiguous_ fastdivmod - Returns the offset of the tensor corresponding to a contiguous layout.
- index_
offset_ with_ layout - Returns the offset of the tensor corresponding to the layout tensor.
- into_
contiguous - Make a jit tensor contiguous.
- into_
contiguous_ packed - Make a jit tensor contiguous, using the pitched allocator if available.
See
create_tensor. Handles unpacking and repacking packed tensors (i.e. quantized values).shaperefers to the actual (unpacked) shape of the tensor, whilepackingspecifies the number of elements in each storage element. - into_
contiguous_ packed_ ref - Make a jit tensor contiguous.
- into_
contiguous_ pitched - Make a jit tensor contiguous, using the pitched allocator if available.
See
create_tensor. - is_
contiguous - Checks if the tensor associated with the given shape and strides is contiguous.
- is_
contiguous_ pitched - Checks if a tensor is only strided on the last dimension, and could be safely reinterpreted as a 2D tensor with unit stride on the last dimension. This will always hold for non-permuted tensors allocated on a runtime.
- launch_
copy_ perpendicular_ ref - Launches the perpendicular contiguous kernel.
- launch_
into_ contiguous_ perpendicular - Launches the perpendicular contiguous kernel.
- matrix_
batch_ layout - Return the layout of a matrix batch given the strides.