pub fn copy_into<R: Runtime>(
client: &ComputeClient<R>,
input: TensorBinding<R>,
output: TensorBinding<R>,
dtype: StorageType,
)Expand description
Copies the input tensor into the output tensor following the strides.
pub fn copy_into<R: Runtime>(
client: &ComputeClient<R>,
input: TensorBinding<R>,
output: TensorBinding<R>,
dtype: StorageType,
)Copies the input tensor into the output tensor following the strides.