Module index_offset_contiguous
cubecl_
std
0.11.0-pre.1
Module index_
offset_
contiguous
Module Items
Structs
Functions
Type Aliases
In cubecl_
std::
tensor
cubecl_std
::
tensor
Module
index_
offset_
contiguous
Structs

_N
Functions

expand
Returns the offset of the tensor corresponding to a contiguous layout.
Type Aliases

N
Type to be used as a generic for launch kernel argument.