Skip to main contentModule index_offset_with_layout
Source - _N1
- _N2
- expand
- Returns the offset of the tensor corresponding to the layout tensor.
- N1
- Type to be used as a generic for launch kernel argument.
- N2
- Type to be used as a generic for launch kernel argument.