pub trait IntoDynExpand {
// Required method
fn __expand_into_dyn_method(
self,
scope: &mut Scope,
) -> <Sequence<i32> as CubeType>::ExpandType;
}Expand description
Coordinates that can be converted to a dynamic sequence of signed coordinates. Can be used to convert any set of coordinates to a comptime-sized sequence for use with TMA.
Required Methods
fn __expand_into_dyn_method( self, scope: &mut Scope, ) -> <Sequence<i32> as CubeType>::ExpandType
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".