IntoDynExpand

Trait IntoDynExpand 

pub trait IntoDynExpand {
    // Required method
    fn __expand_into_dyn_method(
        self,
        scope: &mut Scope,
    ) -> <Sequence<i32> as CubeType>::ExpandType;
}
Coordinates that can be converted to a dynamic sequence of signed coordinates. Can be used to convert any set of coordinates to a comptime-sized sequence for use with TMA.

Required Methods

Implementations on Foreign Types

Source

impl IntoDynExpand for SequenceExpand<i32>

Source

impl IntoDynExpand for SequenceExpand<u32>

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>, ExpandElementTyped<T5>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>, ExpandElementTyped<T5>, ExpandElementTyped<T6>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>, ExpandElementTyped<T5>, ExpandElementTyped<T6>, ExpandElementTyped<T7>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>, ExpandElementTyped<T5>, ExpandElementTyped<T6>, ExpandElementTyped<T7>, ExpandElementTyped<T8>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg, T9: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>, ExpandElementTyped<T5>, ExpandElementTyped<T6>, ExpandElementTyped<T7>, ExpandElementTyped<T8>, ExpandElementTyped<T9>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg, T9: Coordinates + CubePrimitive + LaunchArg, T10: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>, ExpandElementTyped<T5>, ExpandElementTyped<T6>, ExpandElementTyped<T7>, ExpandElementTyped<T8>, ExpandElementTyped<T9>, ExpandElementTyped<T10>)

Source

impl<T0: Coordinates + CubePrimitive + LaunchArg, T1: Coordinates + CubePrimitive + LaunchArg, T2: Coordinates + CubePrimitive + LaunchArg, T3: Coordinates + CubePrimitive + LaunchArg, T4: Coordinates + CubePrimitive + LaunchArg, T5: Coordinates + CubePrimitive + LaunchArg, T6: Coordinates + CubePrimitive + LaunchArg, T7: Coordinates + CubePrimitive + LaunchArg, T8: Coordinates + CubePrimitive + LaunchArg, T9: Coordinates + CubePrimitive + LaunchArg, T10: Coordinates + CubePrimitive + LaunchArg, T11: Coordinates + CubePrimitive + LaunchArg> IntoDynExpand for (ExpandElementTyped<T0>, ExpandElementTyped<T1>, ExpandElementTyped<T2>, ExpandElementTyped<T3>, ExpandElementTyped<T4>, ExpandElementTyped<T5>, ExpandElementTyped<T6>, ExpandElementTyped<T7>, ExpandElementTyped<T8>, ExpandElementTyped<T9>, ExpandElementTyped<T10>, ExpandElementTyped<T11>)

Implementors