Structs
Enums
- Linear
Layout Compilation Arg - Linear
View Layout - Maps a linear index based on vector count to a potentially strided tensor. Only applies the necessary level of striding, either none, only the last dim (for freshly allocated strided tensors), or all dimensions.
- Linear
View Layout Expand
Functions
- linear_
layout - Create a linear layout from a handle and vector size
- linear_
view - Create a linear tensor view from a handle
- linear_
view_ alias - linear_
view_ with_ reference - Create a possibly broadcast linear tensor view from a handle and reference handle
Type Aliases
- Linear
Layout - Concrete version of the layout, so it can be launched on its own
- Linear
Layout Launch - Linear
View Viewwith a linear layout inferred from the shape/strides at launch. Useful for elementwise kernels.- Linear
View Launch - Launch type for
LinearView.