pub struct PermutedLayoutLaunch { /* private fields */ }Implementations
Sourceimpl PermutedLayoutLaunch
impl PermutedLayoutLaunch
Sourcepub fn from_reference_shape(reference_shape: Shape) -> Self
pub fn from_reference_shape(reference_shape: Shape) -> Self
Create a new permuted layout for a possibly broadcast tensor, with a reference shape to be broadcast to.
pub fn from_reference_handle<R: Runtime>( reference_handle: TensorBinding<R>, ) -> Self