pub struct VirtualLayout<C: Coordinates, S: Coordinates> { /* private fields */ }Expand description
A virtual layout, to carry a layout without the need for generic parameters everywhere.
C represents the coordinate space of the underlying layout.
Implementations
Sourceimpl<C: Coordinates, S: Coordinates> VirtualLayout<C, S>
impl<C: Coordinates, S: Coordinates> VirtualLayout<C, S>
Sourcepub fn to_source_pos(&self, pos: C) -> S
pub fn to_source_pos(&self, pos: C) -> S
Virtual version of Layout::to_source_pos
Sourcepub fn to_source_pos_checked(&self, pos: C) -> (S, bool)
pub fn to_source_pos_checked(&self, pos: C) -> (S, bool)
Virtual version of Layout::to_source_pos_checked
Sourcepub fn shape(&self) -> C
pub fn shape(&self) -> C
Virtual version of Layout::shape
Sourcepub fn is_in_bounds(&self, pos: C) -> bool
pub fn is_in_bounds(&self, pos: C) -> bool
Virtual version of Layout::is_in_bounds
pub fn __expand_to_source_pos( scope: &mut Scope, this: <Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, ) -> <S as CubeType>::ExpandType
pub fn __expand_to_source_pos_checked( scope: &mut Scope, this: <Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, ) -> <(S, bool) as CubeType>::ExpandType
pub fn __expand_shape( scope: &mut Scope, this: <Self as CubeType>::ExpandType, ) -> <C as CubeType>::ExpandType
pub fn __expand_is_in_bounds( scope: &mut Scope, this: <Self as CubeType>::ExpandType, pos: <C as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
Sourceimpl<C: Coordinates, S: Coordinates> VirtualLayout<C, S>
impl<C: Coordinates, S: Coordinates> VirtualLayout<C, S>
Sourcepub fn new<L: Layout<Coordinates = C, SourceCoordinates = S>>(
_layout: L,
) -> VirtualLayout<C, S>
pub fn new<L: Layout<Coordinates = C, SourceCoordinates = S>>( _layout: L, ) -> VirtualLayout<C, S>
Create a new virtual layout from a concrete one
Sourcepub fn __expand_new<L: Layout<Coordinates = C, SourceCoordinates = S> + 'static>(
_scope: &mut Scope,
layout: L::ExpandType,
) -> VirtualLayoutExpand<C, S>
pub fn __expand_new<L: Layout<Coordinates = C, SourceCoordinates = S> + 'static>( _scope: &mut Scope, layout: L::ExpandType, ) -> VirtualLayoutExpand<C, S>
Expand function of VirtualLayout::__expand_new