TensorHandle

Struct TensorHandle 

pub struct TensorHandle<R>
where R: Runtime,
{ pub handle: Handle, pub metadata: Box<Metadata>, pub dtype: ElemType, /* private fields */ }
Tensor representation containing a server handle as well as basic tensor metadata.,

Fields

handle: Handle

The buffer where the data are stored.

metadata: Box<Metadata>dtype: ElemType

The type used as storage.

Implementations

Source

impl<R> TensorHandle<R>
where R: Runtime,

pub fn new( handle: Handle, shape: impl Into<Shape>, strides: impl Into<Strides>, storage: impl Into<Type>, ) -> Self

Create a new tensor.

pub fn empty( client: &ComputeClient<R>, shape: impl Into<Shape>, storage: impl Into<Type>, ) -> Self

pub fn new_contiguous( shape: impl Into<Shape>, handle: Handle, storage: ElemType, ) -> Self

Create a new tensor with a contiguous memory layout.

pub fn can_mut(&self) -> bool

Check if the tensor is safe to mutate.

pub fn binding(self) -> TensorBinding<R>

pub fn into_arg(self) -> TensorArg<R>

Return the reference to a tensor argument.

pub fn into_copy_descriptor(self) -> CopyDescriptor

pub fn required_address_type(&self) -> AddressType

pub fn shape(&self) -> &Shape

pub fn strides(&self) -> &Strides

Source

impl<R> TensorHandle<R>
where R: Runtime,

pub fn zeros( client: &ComputeClient<R>, shape: impl Into<Shape>, dtype: impl Into<Type>, ) -> Self