Module throughput

Module throughput 

Throughput utilities.

Modules

compute_cmma
compute_direct
launch_overhead
memory_direct
memory_probe
memory_read
memory_write

Structs

LaunchConfig
Hardware execution parameters for launching a compute kernel.

Functions

device_throughput
Measure peak throughput on device for each of the given keys.
measure_memory_curve
Measure the memory ceiling across a range of working sets, from a few kilobytes up to as much as the device will allocate.
measure_peak_throughput
Computes the peak throughput for a given runtime and key.
roofline_bounds
Calculates roofline autotune bounds for a given Work amount and compute throughput key.