Throughput utilities.
Modules
Structs
- Launch
Config - Hardware execution parameters for launching a compute kernel.
Functions
- device_
throughput - Measure peak throughput on
devicefor each of the givenkeys. - measure_
memory_ curve - Measure the memory ceiling across a range of working sets, from a few kilobytes up to as much as the device will allocate.
- measure_
peak_ throughput - Computes the peak throughput for a given runtime and key.
- roofline_
bounds - Calculates roofline autotune bounds for a given
Workamount and compute throughput key.