Module throughput

Module throughput 

Throughput utilities.

Modules

compute_cmma
compute_direct
launch_overhead
memory_direct

Structs

LaunchConfig
Hardware execution parameters for launching a compute kernel.

Functions

device_throughput
Measure peak throughput on device for each of the given keys.
measure_peak_throughput
Computes the peak throughput for a given runtime and key.
roofline_bounds
Calculates roofline autotune bounds for a given Work amount and compute throughput key.