Module throughput

Module throughput 

Throughput utilities.

Modules

compute_cmma
compute_direct
launch_overhead
memory_direct

Structs

LaunchConfig
Hardware execution parameters for launching a compute kernel.

Functions

measure_launch_overhead
Measures the fixed cost of a single kernel launch.
measure_peak_throughput
Computes the peak throughput for a given runtime and key.