Throughput utilities.
Modules
Structs
- Launch
Config - Hardware execution parameters for launching a compute kernel.
Functions
- measure_
launch_ overhead - Measures the fixed cost of a single kernel launch.
- measure_
peak_ throughput - Computes the peak throughput for a given runtime and key.