pub fn roofline_bounds<R: Runtime>(
client: &ComputeClient<R>,
compute_key: ThroughputKey,
work: Work,
thresholds: Thresholds,
) -> BoundsExpand description
Calculates roofline autotune bounds for a given Work amount and compute throughput key.
Measures compute and memory peak throughputs along with launch overhead for the runtime client.