Module memory_direct_throughput
cubecl_
std
0.11.0-pre.1
Module memory_
direct_
throughput
Module Items
Structs
Functions
Type Aliases
In cubecl_
std::
throughput::
memory_
direct
cubecl_std
::
throughput
::
memory_direct
Module
memory_
direct_
throughput
Structs

Memory
Direct
Throughput
memory_direct_throughput Kernel
Memory
Direct
Throughput
Info
_I
_N
Functions

expand
launch_
unchecked
⚠
Launch the kernel
memory_direct_throughput()
on the given runtime without bound checks.
Type Aliases

I
Type to be used as a generic for launch kernel argument.
N
Type to be used as a generic for launch kernel argument.